//
//  NekoController.h
//  Neko Type-R

/*
Copyright (c) 2005 Vince Tagle <vtagle@newsguy.com>

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
documentation files (the "Software"), to deal in the Software without restriction, including without limitation 
the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and 
to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of 
the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO 
THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE 
SOFTWARE.
*/

#import <Cocoa/Cocoa.h>


@class NekoView;
@class NekoHelpController; 
@class NekoPrefsController; 
@class CatNamesController; 

@interface NekoController : NSObject 
{
	IBOutlet NSWindow*		mainWindow; 
	IBOutlet NekoView*		nekoView; 
	IBOutlet NSTextField*	raceMessageField; 
	IBOutlet NSTextField*	playerWPMField; 
	IBOutlet NSTextField*	computerWPMField; 
	IBOutlet NSPanel*		donationPanel; 
	
	NekoHelpController*		helpController;
	NekoPrefsController*	prefsController; 
	CatNamesController*		catNamesController; 
	
	BOOL	donationSolicited; 
}

- (IBAction)newGame: (id)sender; 
- (IBAction)displayHelp: (id)sender; 
- (IBAction)displayPrefs: (id)sender; 
- (IBAction)displayCatNames: (id)sender; 
- (IBAction)endCurrentGame: (id)sender;
- (void)updateRaceMessage: (NSString *)message; 
- (void)updatePlayerWordsPerMinute: (UInt32)wpm; 
- (void)updateComputerWordsPerMinute: (UInt32)wpm; 
- (void)handleNewRaceMessage: (NSNotification *)note; 
- (void)handleEndCurrentRace: (NSNotification *)note;
- (BOOL)applicationShouldTerminateAfterLastWindowClosed: (NSApplication *)theApplication;
- (BOOL)validateMenuItem: (NSMenuItem *)item;

/*! \brief  Closes the donation solicitation sheet and never shows it again.
*/
- (IBAction)userDonated: (id)sender; 

/*! \brief  Closes the donation solicitation sheet. 
*/
- (IBAction)closeDonationSheet: (id)sender; 

/*!	\brief	Opens the website. 
*/
- (IBAction)openWebsite: (id)sender; 

/*!	\brief	Opens the donation page of the website. 
*/
- (IBAction)openDonationPage: (id)sender; 

/*!	\brief	Send an e-mail to me. 
*/
- (IBAction)sendEmail: (id)sender; 

/*!	\brief	Check for software updates. 
*/
- (IBAction)checkForUpdates: (id)sender; 

- (IBAction)validateLicenseFile: (id)sender; 
- (void)openLicenseFilePanelDidEnd: (NSOpenPanel *)panel returnCode: (int)returnCode contextInfo: (void  *)contextInfo;
- (NSString *)checkLicenseFile: (NSString *)licensePath;
- (NSString *)checkLicense: (NSData *)licenseData;

- (BOOL)application: (NSApplication *)theApplication openFile: (NSString *)filename;

@end
