//
//  NekoTypingTeam.h
//  Neko Type-R

/*
Copyright (c) 2005 Vince Tagle <vtagle@newsguy.com>

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
documentation files (the "Software"), to deal in the Software without restriction, including without limitation 
the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and 
to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of 
the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO 
THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE 
SOFTWARE.
*/

#import <Cocoa/Cocoa.h>
#include "NekoConstants.h"


@class NekoTyper; 
@class NekoView; 
@class WordDispenser; 

enum
{
	kMatchNoMatchFound, 
	kMatchPartialMatchFound, 
	kMatchCompleteMatchFound, 
	kMatchCodesMax
};

@interface NekoTypingTeam : NSObject 
{
	UInt8		teamID;
	NSImage*	nekoImages; 
	NSSize		nekoSize; 
	float		fontHeight; 
	BOOL		waitingForRaceToStart; 
	NekoView*	parentView; 
	
	BOOL		computerControlled; 
	NekoTyper*	selectedComputerNeko; 
	UInt8		charactersMatched; 
	UInt32		updateCharactersMatchedInterval; 
	UInt32		updateCharactersMatchedAtTime; 
	BOOL		catnipped; 
	
	NSImage*	powerupImages[kPowerupMax]; 
	UInt32		generateNextPowerupAtTime; 
	UInt32		powerupGenerationInterval; 
	UInt32		chanceOfPowerupAtInterval; 
	SInt32		powerupType; 
	float		powerupPosition; 
	NekoTyper*	nekoWithPowerup; 
	
	NSMutableArray*	teamMembers; 
	NSDictionary*	defaultTextAttributes; 
	NSDictionary*	catNameTextAttributes; 
	
	UInt32			numberOfWordsTyped; 
	UInt32			updateWordsPerMinuteAtTime; 
	UInt32			leftoverTimeInMinute; 
	UInt32			numMistypedWords; 
	NSMutableArray*	wordsPerMinute; 
}

- (void)loadTeamImages: (NSString *)name; 
- (void)addTeamMember: (NekoTyper *)neko; 
- (void)updateTeam; 
- (float)drawTeamAtHeight: (float)yAdjustment; 
- (void)resetTeam: (BOOL)newGame isComputerControlled: (BOOL)computerControl; 
- (SInt32)matchCharactersTyped: (NSString *)charactersTyped; 
- (BOOL)finishedRace; 
- (void)startComputerControl; 
- (void)updateComputerControl; 
- (void)increaseComputerDifficulty; 
- (void)startRacing; 
- (void)raceEnded; 
- (void)powerdownEffect: (SInt32)type withSound: (BOOL)sound; 
- (float)getTypingAccuracy; 
- (void)setTeamWordList: (WordDispenser *)wordList; 
- (void)removeTeamMembers; 

@end
